/**
 * Copyright: Copyright (c) 2009 Jacob Carlborg.
 * Authors: Jacob Carlborg
 * Version: Initial created: Sep 25, 2009 
 * License: $(LINK2 http://www.boost.org/LICENSE_1_0.txt, Boost Software License 1.0)
 */
module dstep.coredata.NSEntityMapping;

import dstep.coredata.NSEntityDescription;
import dstep.foundation.NSArray;
import dstep.foundation.NSData;
import dstep.foundation.NSDictionary;
import dstep.foundation.NSExpression;
import dstep.foundation.NSObjCRuntime;
import dstep.foundation.NSObject;
import dstep.foundation.NSString;
import dstep.objc.bridge.Bridge;
import dstep.objc.objc;

alias NSUInteger NSEntityMappingType;

enum
{
	NSUndefinedEntityMappingType = 0x00,
	NSCustomEntityMappingType = 0x01,
	NSAddEntityMappingType = 0x02,
	NSRemoveEntityMappingType = 0x03,
	NSCopyEntityMappingType = 0x04,
	NSTransformEntityMappingType = 0x05
}

class NSEntityMapping : NSObject
{
	mixin (ObjcWrap);

	NSString name ()
	{
		return invokeObjcSelf!(NSString, "name");
	}

	void setName (NSString name)
	{
		return invokeObjcSelf!(void, "setName:", NSString)(name);
	}

	uint mappingType ()
	{
		return invokeObjcSelf!(uint, "mappingType");
	}

	void setMappingType (uint type)
	{
		return invokeObjcSelf!(void, "setMappingType:", uint)(type);
	}

	NSString sourceEntityName ()
	{
		return invokeObjcSelf!(NSString, "sourceEntityName");
	}

	void setSourceEntityName (NSString name)
	{
		return invokeObjcSelf!(void, "setSourceEntityName:", NSString)(name);
	}

	NSData sourceEntityVersionHash ()
	{
		return invokeObjcSelf!(NSData, "sourceEntityVersionHash");
	}

	void setSourceEntityVersionHash (NSData vhash)
	{
		return invokeObjcSelf!(void, "setSourceEntityVersionHash:", NSData)(vhash);
	}

	NSString destinationEntityName ()
	{
		return invokeObjcSelf!(NSString, "destinationEntityName");
	}

	void setDestinationEntityName (NSString name)
	{
		return invokeObjcSelf!(void, "setDestinationEntityName:", NSString)(name);
	}

	NSData destinationEntityVersionHash ()
	{
		return invokeObjcSelf!(NSData, "destinationEntityVersionHash");
	}

	void setDestinationEntityVersionHash (NSData vhash)
	{
		return invokeObjcSelf!(void, "setDestinationEntityVersionHash:", NSData)(vhash);
	}

	NSArray attributeMappings ()
	{
		return invokeObjcSelf!(NSArray, "attributeMappings");
	}

	void setAttributeMappings (NSArray mappings)
	{
		return invokeObjcSelf!(void, "setAttributeMappings:", NSArray)(mappings);
	}

	NSArray relationshipMappings ()
	{
		return invokeObjcSelf!(NSArray, "relationshipMappings");
	}

	void setRelationshipMappings (NSArray mappings)
	{
		return invokeObjcSelf!(void, "setRelationshipMappings:", NSArray)(mappings);
	}

	NSExpression sourceExpression ()
	{
		return invokeObjcSelf!(NSExpression, "sourceExpression");
	}

	void setSourceExpression (NSExpression source)
	{
		return invokeObjcSelf!(void, "setSourceExpression:", NSExpression)(source);
	}

	NSDictionary userInfo ()
	{
		return invokeObjcSelf!(NSDictionary, "userInfo");
	}

	void setUserInfo (NSDictionary dict)
	{
		return invokeObjcSelf!(void, "setUserInfo:", NSDictionary)(dict);
	}

	NSString entityMigrationPolicyClassName ()
	{
		return invokeObjcSelf!(NSString, "entityMigrationPolicyClassName");
	}

	void setEntityMigrationPolicyClassName (NSString name)
	{
		return invokeObjcSelf!(void, "setEntityMigrationPolicyClassName:", NSString)(name);
	}
}

